@@ -22,7 +22,7 @@
 
 ;;; Commentary:
 
-;; This library implement ICCCM the same way as xcb/util-wm.
+;; This library implements ICCCM the same way as xcb/util-wm.
 
 ;; Usage tips:
 ;; + Do not forget to call `xcb:icccm:init' for _every_ connection using
@@ -40,6 +40,7 @@
 
 ;;; Code:
 
+(eval-when-compile (require 'cl-lib))
 (require 'xcb)
 
 ;;;; ICCCM atoms
@@ -57,7 +58,8 @@
   "Initialize ICCCM module.
 
 This method must be called before using any other method in this module."
-  (xcb:icccm:intern-atoms obj xcb:icccm:-atoms))
+  (unless xcb:Atom:WM_PROTOCOLS
+    (xcb:icccm:intern-atoms obj xcb:icccm:-atoms)))
 
 (cl-defmethod xcb:icccm:intern-atoms ((obj xcb:connection) atoms)
   "Intern the X atoms listed in the list AOTMS.
@@ -84,7 +86,7 @@ The value of these atoms will be available in `xcb:Atom' namespace."
 
 (defclass xcb:icccm:--ClientMessage ()
   ((data :type xcb:-ignore))            ;shadowed slot
-  :documentation "To shadow the data slot in `xcb:SendEvent'.")
+  :documentation "To shadow the data slot in `xcb:ClientMessage'.")
 ;;
 (defclass xcb:icccm:-ClientMessage
   (xcb:icccm:--ClientMessage xcb:ClientMessage)
