@@ -49,7 +49,7 @@
 
 ;;; Code:
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (require 'cl-generic)
 (require 'eieio)
 
